pyxmpp.jabber.dataforms

Package pyxmpp :: Package jabber :: Module dataforms |
[hide private]

# Module dataforms

source code

Jabber Data Forms support.

Normative reference:
  - JEP 4

Classes | [hide private]
| Option One of optional data form field values.
| Field A data form field.
| Item An item of multi-item form data (e.g.
| Form A JEP-0004 compliant data form.

Variables | [hide private]
| __revision__ = ``'``$Id: disco.py 513 2005-01-09 16:34:00Z jajcus $``'``
| DATAFORM_NS = ``'``jabber:x:data``'``
| __package__ = ``'``pyxmpp.jabber``'``

Imports: copy, libxml2, warnings, StanzaPayloadObject, from_utf8, to_utf8, xml_element_ns_iter, JID, BadRequestProtocolError